ardt.datasets.AERDataset
========================

.. currentmodule:: ardt.datasets

.. autoclass:: AERDataset

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AERDataset.__init__
      ~AERDataset.get_media_name_by_movie_id
      ~AERDataset.get_signal_metadata
      ~AERDataset.get_trial_splits
      ~AERDataset.get_working_dir
      ~AERDataset.get_working_path
      ~AERDataset.load_trials
      ~AERDataset.preload
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AERDataset.expected_media_responses
      ~AERDataset.media_file_offset
      ~AERDataset.media_ids
      ~AERDataset.participant_ids
      ~AERDataset.participant_offset
      ~AERDataset.signal_preprocessors
      ~AERDataset.signals
      ~AERDataset.trials
   
   